import { e as error, d as private_env } from './index-CTfgkdxe.js';
import { create } from 'youtube-dl-exec';
import { spawn } from 'node:child_process';

const YTDLP_PATH = private_env.YTDLP_PATH;
const ytdl = create(YTDLP_PATH);
async function getYouTubeMetadata(link) {
  return await ytdl(link, {
    dumpSingleJson: true,
    noCheckCertificates: true,
    noWarnings: true,
    preferFreeFormats: true
  });
}
function streamYouTube(link, format) {
  return new ReadableStream({
    start(controller) {
      const args = [
        "-o",
        "-",
        format === "mp3" ? "--embed-metadata" : "",
        "--format",
        format === "mp3" ? "bestaudio" : "best",
        "--audio-format",
        format === "mp3" ? "mp3" : "",
        "--no-playlist"
      ].filter(Boolean);
      const process = spawn("yt-dlp", [...args, link], { stdio: ["ignore", "pipe", "ignore"] });
      process.stdout.on("data", (chunk) => controller.enqueue(chunk));
      process.stdout.on("end", () => controller.close());
      process.stdout.on("error", (err) => {
        console.error("Stream error:", err);
        controller.error(err);
      });
    }
  });
}
const GET = async ({ url }) => {
  const link = url.searchParams.get("link");
  const format = url.searchParams.get("format");
  const source = url.searchParams.get("source");
  if (!link || !format || !source) {
    throw error(400, "Missing required query parameters: link, format, or source");
  }
  if (source !== "youtube") {
    throw error(400, "Currently, only YouTube is supported");
  }
  try {
    const metadata = await getYouTubeMetadata(link);
    const { title, uploader } = metadata;
    const safeTitle = `${uploader} - ${title}`;
    const filename = `${safeTitle}.${format}`;
    console.log(filename);
    return new Response(streamYouTube(link, format), {
      headers: {
        "Content-Type": format === "mp3" ? "audio/mpeg" : "video/mp4",
        "Content-Disposition": `attachment; filename="${filename}"`
      }
    });
  } catch (err) {
    console.error("Error fetching metadata:", err);
    throw error(500, "Failed to fetch video metadata");
  }
};

export { GET };
//# sourceMappingURL=_server.ts-OxMXw5OO.js.map
